macro_rules! debug_println {
($($arg:tt)*) => { ... };
}Expand description
Debug print macro that only prints when the debug_logging feature is enabled
macro_rules! debug_println {
($($arg:tt)*) => { ... };
}Debug print macro that only prints when the debug_logging feature is enabled