Macro try_log

macro_rules! try_log {
    ($expr:expr, $msg:expr) => { ... };
    (option $expr:expr, $msg:expr) => { ... };
}
Try to log an error if Result is Err or Option is None, then return the value.