PooledRecord

Struct PooledRecord 

pub struct PooledRecord { /* private fields */ }
A record acquired from a pool that will be returned when dropped

Implementations

Source

impl PooledRecord

pub fn get_mut(&mut self) -> &mut Record

Get a mutable reference to the record

pub fn get(&self) -> &Record

Get a reference to the record

pub fn into_record(self) -> Record

Take ownership of the record, preventing it from being returned to the pool

pub fn set_level(&mut self, level: LogLevel)

Set the log level

pub fn set_message(&mut self, message: impl Into<String>)

Set the message

Methods from Deref<Target = Record>

pub fn level(&self) -> LogLevel

Get the log level

pub fn message(&self) -> &str

Get the log message

pub fn module(&self) -> &str

Get the module path

pub fn file(&self) -> &str

Get the file name

pub fn line(&self) -> u32

Get the line number

pub fn timestamp(&self) -> DateTime<Utc>

Get the timestamp

pub fn metadata(&self) -> &HashMap<String, String>

Get the metadata

pub fn context(&self) -> &HashMap<String, Value>

Get the context data

pub fn get_metadata(&self, key: &str) -> Option<&str>

Returns the value associated with the given key, if any.

pub fn get_context(&self, key: &str) -> Option<&Value>

Returns the context value associated with the given key, if any.

pub fn has_context(&self) -> bool

Returns true if the record has any structured context data.

pub fn has_metadata(&self) -> bool

Returns true if the record has any metadata.

pub fn has_formatter(&self) -> bool

Returns true if the record has a deferred formatter.

pub fn context_len(&self) -> usize

Returns the number of context entries in the record.

pub fn metadata_len(&self) -> usize

Returns the number of metadata entries in the record.

pub fn location(&self) -> String

Get the location as a string in the format “file:line”