macro_rules! try_log {
($expr:expr, $msg:expr) => { ... };
(option $expr:expr, $msg:expr) => { ... };
}Expand description
Try to log an error if Result is Err or Option is None, then return the value.
macro_rules! try_log {
($expr:expr, $msg:expr) => { ... };
(option $expr:expr, $msg:expr) => { ... };
}Try to log an error if Result is Err or Option is None, then return the value.